# Pemuda Persis Bot

A dedicated chatbot for Pemuda Persis Digital Media.

### Telegram Account : 

- Production : [@pemudapersis_bot](t.me/pemudapersis_bot)
- Development : [@pemudapersisdev_bot](t.me/pemudapersisdev_bot)

### Installation :

To install the bot, we can simply use pip command :

```shell
pip install pemudapersis-bot
```
The package is available in [Pypi](https://pypi.org/project/pemudapersis-bot).

### Start the bot :
#### Polling method

```shell
export BOT_TOKEN=<bot token>
pemudapersis-bot --poll
```

#### Webhook method

```shell
export BOT_TOKEN=<bot token>
pemudapersis-bot --start
```

Please contact @zamzambadruzaman for the bot token.

For contributing please check [CONTRIBUTING](CONTRIBUTING.md)
